@@ -1,7 +1,7 @@
 # (c) 2005 Ian Bicking and contributors; written for Paste (http://pythonpaste.org)
 # Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
 
-class FileMixin(object):
+class FileMixin:
 
     """
     Used to provide auxiliary methods to objects simulating files.
